@@ -14,7 +14,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with libntlm; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301, USA.
  *
  */
 
@@ -30,7 +31,7 @@ extern "C"
   typedef unsigned int uint32;
   typedef unsigned char uint8;
 
-#define NTLM_VERSION "0.3.6"
+#define NTLM_VERSION "0.3.7"
 
 /*
  * These structures are byte-order dependant, and should not
@@ -103,6 +104,9 @@ extern "C"
 			      tSmbNtlmAuthResponse * response,
 			      const char *user, const char *password);
 
+  extern const char *
+  ntlm_check_version (const char *req_version);
+
 # ifdef __cplusplus
 }
 # endif
